timeout_at

Function timeout_at 

pub fn timeout_at<F>(deadline: Instant, future: F) -> Timeout<F> 
where F: Future,
Available on crate features runtime and time only.
Require a Future to complete before the specified instant in time.

If the future completes before the instant is reached, then the completed value is returned. Otherwise, an error is returned.

Panics

Panic if not running under a Runtime.